Stan Math Library: stan/math/prim/mat/fun/autocovariance.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

autocovariance.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_AUTOCOVARIANCE_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_AUTOCOVARIANCE_HPP
3
4 #include <stan/math/prim/mat/fun/autocorrelation.hpp>
5 #include <stan/math/prim/mat/fun/variance.hpp>
6 #include <vector>
7
8 namespace stan {
9
10 namespace math {
11
12
33 template <typename T>
34 void autocovariance(const std::vector<T>& y,
35 std::vector<T>& acov,
36 Eigen::FFT<T>& fft) {
37 stan::math::autocorrelation(y, acov, fft);
38
39 T var = stan::math::variance(y) * (y.size()-1) / y.size();
40 for (size_t i = 0; i < y.size(); i++) {
41 acov[i] *= var;
42 }
43 }
44
61 template <typename T>
62 void autocovariance(const std::vector<T>& y,
63 std::vector<T>& acov) {
64 Eigen::FFT<T> fft;
65 autocovariance(y, acov, fft);
66 }
67
68
69 }
70 }
71
72 #endif
variance.hpp
stan
Definition: log_sum_exp.hpp:8
autocorrelation.hpp
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
stan::math::variance
boost::math::tools::promote_args< T >::type variance(const std::vector< T > &v)
Returns the sample variance (divide by length - 1) of the coefficients in the specified standard vect...
Definition: variance.hpp:24
stan::math::autocovariance
void autocovariance(const std::vector< T > &y, std::vector< T > &acov, Eigen::FFT< T > &fft)
Write autocovariance estimates for every lag for the specified input sequence into the specified resu...
Definition: autocovariance.hpp:34
stan::math::autocorrelation
void autocorrelation(const std::vector< T > &y, std::vector< T > &ac, Eigen::FFT< T > &fft)
Write autocorrelation estimates for every lag for the specified input sequence into the specified res...
Definition: autocorrelation.hpp:54

[ Stan Home Page ] © 2011–2016, Stan Development Team.